<?php

namespace IQBall\Api\Controller;

use Exception;
use IQBall\App\Control;
use IQBall\Core\Data\Account;
use IQBall\Core\Http\HttpCodes;
use IQBall\Core\Http\HttpRequest;
use IQBall\Core\Http\HttpResponse;
use IQBall\Core\Http\JsonHttpResponse;
use IQBall\Core\Model\AuthModel;
use IQBall\Core\Validation\FieldValidationFail;
use IQBall\Core\Validation\Validator;
use IQBall\Core\Validation\Validators;

/**
 * API endpoint related to tactics
 */
class APIUserController {
    private AuthModel $model;

    /**
     * @param AuthModel $model
     */
    public function __construct(AuthModel $model) {
        $this->model = $model;
    }

    /**
     * @param Account $account
     * @return HttpResponse
     */
    public function updateProfile(Account $account): HttpResponse {
        return Control::runChecked([
            "name" => [Validators::name()],
            "email" => [Validators::email()]
        ], function (HttpRequest $request) use ($account) {

            $failures = $this->model->updateProfile($request["name"], $request["email"], $account->getUser()->getId());

            if (!empty($failures)) {
                //TODO find a system to handle Unauthorized error codes more easily from failures.
                
                return new JsonHttpResponse($failures, HttpCodes::BAD_REQUEST);
            }

            return HttpResponse::fromCode(HttpCodes::OK);
        });
    }


    function testImage(string $lien) {
        try {
            $headers = get_headers($lien, 1);
    
            // Vérifier le statut de la réponse (200 OK est considéré comme valide)
            $statusCode = explode(' ', $headers[0])[1];
            if ($statusCode === '200') {
                // Vérifier le type de contenu pour s'assurer qu'il s'agit d'une image
                $contentType = $headers['Content-Type'];
                if ($contentType && strpos($contentType, 'image/') === 0) {
                    return true;
                }
            }
            return false;
        } catch (Exception $error) {
            return false;
        }
    }

    /**
     * @param Account $account
     * @return HttpResponse
     */
    public function updatePicture(Account $account): HttpResponse {
        return Control::runChecked([
            "lien" => [Validators::everything()]
        ], function (HttpRequest $request) use ($account) {
            error_log("test");

            $failures = $this->model->updatePicture($request["lien"], $account->getUser()->getId());

            if (!empty($failures)) {
                //TODO find a system to handle Unauthorized error codes more easily from failures.
                
                return new JsonHttpResponse($failures, HttpCodes::BAD_REQUEST);
            }

            return HttpResponse::fromCode(HttpCodes::OK);
        });

        // error_log("Test");
        // return new HttpResponse(HttpCodes::OK, []);
    }
}